@@ -1,23 +1,8 @@
-from dotenv import load_dotenv
 from langchain.tools import tool
-from langchain_qwq import ChatQwen
 from langchain_core.messages import HumanMessage, ToolMessage
 
 from langchain_dev_utils.agents import create_agent
 from langchain_dev_utils.agents.middleware import ModelRouterMiddleware
-from langchain_dev_utils.chat_models import batch_register_model_provider
-
-load_dotenv()
-
-batch_register_model_provider(
-    [
-        {
-            "provider_name": "dashscope",
-            "chat_model": ChatQwen,
-        },
-        {"provider_name": "zai", "chat_model": "openai-compatible"},
-    ]
-)
 
 
 @tool
